==> grafana-alloy-debug-1.11.2-3-x86_64.pkg.tar.zst: usr/src/debug/grafana-alloy/pkg/mod/github.com/!data!dog/datadog-api-client-go/v2@v2.44.0/api/datadogV2/model_gcp_usage_cost_config_patch_request_type.go <==
// Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
// This product includes software developed at Datadog (https://www.datadoghq.com/).
// Copyright 2019-Present Datadog, Inc.

package datadogV2

import (
	"fmt"

	"github.com/DataDog/datadog-api-client-go/v2/api/datadog"
)

// GCPUsageCostConfigPatchRequestType Type of GCP Usage Cost config patch request.
type GCPUsageCostConfigPatchRequestType string

// List of GCPUsageCostConfigPatchRequestType.
const (
	GCPUSAGECOSTCONFIGPATCHREQUESTTYPE_GCP_USAGE_COST_CONFIG_PATCH_REQUEST GCPUsageCostConfigPatchRequestType = "gcp_uc_config_patch_request"
)

var allowedGCPUsageCostConfigPatchRequestTypeEnumValues = []GCPUsageCostConfigPatchRequestType{
	GCPUSAGECOSTCONFIGPATCHREQUESTTYPE_GCP_USAGE_COST_CONFIG_PATCH_REQUEST,
}

// GetAllowedValues reeturns the list of possible values.
func (v *GCPUsageCostConfigPatchRequestType) GetAllowedValues() []GCPUsageCostConfigPatchRequestType {
	return allowedGCPUsageCostConfigPatchRequestTypeEnumValues
}

// UnmarshalJSON deserializes the given payload.
func (v *GCPUsageCostConfigPatchRequestType) UnmarshalJSON(src []byte) error {
	var value string
	err := datadog.Unmarshal(src, &value)
	if err != nil {
		return err
	}
	*v = GCPUsageCostConfigPatchRequestType(value)
	return nil
}

// NewGCPUsageCostConfigPatchRequestTypeFromValue returns a pointer to a valid GCPUsageCostConfigPatchRequestType
// for the value passed as argument, or an error if the value passed is not allowed by the enum.
func NewGCPUsageCostConfigPatchRequestTypeFromValue(v string) (*GCPUsageCostConfigPatchRequestType, error) {
	ev := GCPUsageCostConfigPatchRequestType(v)
	if ev.IsValid() {
		return &ev, nil
	}
	return nil, fmt.Errorf("invalid value '%v' for GCPUsageCostConfigPatchRequestType: valid values are %v", v, allowedGCPUsageCostConfigPatchRequestTypeEnumValues)
}

// IsValid return true if the value is valid for the enum, false otherwise.
func (v GCPUsageCostConfigPatchRequestType) IsValid() bool {
	for _, existing := range allowedGCPUsageCostConfigPatchRequestTypeEnumValues {
		if existing == v {
			return true
		}
	}
	return false
}

// Ptr returns reference to GCPUsageCostConfigPatchRequestType value.
func (v GCPUsageCostConfigPatchRequestType) Ptr() *GCPUsageCostConfigPatchRequestType {
	return &v
}

==> grafana-alloy-debug-1.12.2-1-x86_64.pkg.tar.zst: usr/src/debug/grafana-alloy/pkg/mod/github.com/!data!dog/datadog-api-client-go/v2@v2.48.0/api/datadogV2/model_gcp_usage_cost_config_patch_request_type.go <==
// Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
// This product includes software developed at Datadog (https://www.datadoghq.com/).
// Copyright 2019-Present Datadog, Inc.

package datadogV2

import (
	"fmt"

	"github.com/DataDog/datadog-api-client-go/v2/api/datadog"
)

// GCPUsageCostConfigPatchRequestType Type of Google Cloud Usage Cost config patch request.
type GCPUsageCostConfigPatchRequestType string

// List of GCPUsageCostConfigPatchRequestType.
const (
	GCPUSAGECOSTCONFIGPATCHREQUESTTYPE_GCP_USAGE_COST_CONFIG_PATCH_REQUEST GCPUsageCostConfigPatchRequestType = "gcp_uc_config_patch_request"
)

var allowedGCPUsageCostConfigPatchRequestTypeEnumValues = []GCPUsageCostConfigPatchRequestType{
	GCPUSAGECOSTCONFIGPATCHREQUESTTYPE_GCP_USAGE_COST_CONFIG_PATCH_REQUEST,
}

// GetAllowedValues reeturns the list of possible values.
func (v *GCPUsageCostConfigPatchRequestType) GetAllowedValues() []GCPUsageCostConfigPatchRequestType {
	return allowedGCPUsageCostConfigPatchRequestTypeEnumValues
}

// UnmarshalJSON deserializes the given payload.
func (v *GCPUsageCostConfigPatchRequestType) UnmarshalJSON(src []byte) error {
	var value string
	err := datadog.Unmarshal(src, &value)
	if err != nil {
		return err
	}
	*v = GCPUsageCostConfigPatchRequestType(value)
	return nil
}

// NewGCPUsageCostConfigPatchRequestTypeFromValue returns a pointer to a valid GCPUsageCostConfigPatchRequestType
// for the value passed as argument, or an error if the value passed is not allowed by the enum.
func NewGCPUsageCostConfigPatchRequestTypeFromValue(v string) (*GCPUsageCostConfigPatchRequestType, error) {
	ev := GCPUsageCostConfigPatchRequestType(v)
	if ev.IsValid() {
		return &ev, nil
	}
	return nil, fmt.Errorf("invalid value '%v' for GCPUsageCostConfigPatchRequestType: valid values are %v", v, allowedGCPUsageCostConfigPatchRequestTypeEnumValues)
}

// IsValid return true if the value is valid for the enum, false otherwise.
func (v GCPUsageCostConfigPatchRequestType) IsValid() bool {
	for _, existing := range allowedGCPUsageCostConfigPatchRequestTypeEnumValues {
		if existing == v {
			return true
		}
	}
	return false
}

// Ptr returns reference to GCPUsageCostConfigPatchRequestType value.
func (v GCPUsageCostConfigPatchRequestType) Ptr() *GCPUsageCostConfigPatchRequestType {
	return &v
}
